@@ -421,8 +421,10 @@ def upload_excel_s3(local_file, bucket, s3_file):
 #Upload excel file to ceph
 def upload_excel_ceph(local_file, bucket, s3_file):
     try:
+        print("upload to excel file function in utilities")
         s3 = get_s3_ceph()
-        s3.upload_file(Filename = local_file, Key = s3_file)
+        s3.Bucket(BUCKET_NAME).upload_file(Filename = local_file, Key = s3_file)
+        logger.info('Upload successful')
         
         delete_excel_file(local_file)
         return s3_file
